@@ -274,7 +274,7 @@ class IDPIntType(IDPType):
 class IDPIntRangeType(IDPIntType):
 
     def in_vocabulary(self):
-        return ("type {} = {{{}}}"
+        return ("type {} = {{{}}} isa int"
                 .format(super(IDPType, self).in_vocabulary(),
                         self.show_contents()))
 
@@ -294,7 +294,7 @@ class IDPFloatType(IDPType):
 class IDPFloatRangeType(IDPFloatType):
 
     def in_vocabulary(self):
-        return ("type {} = {{{}}}"
+        return ("type {} = {{{}}} isa float"
                 .format(super(IDPType, self).in_vocabulary(),
                         self.show_contents()))
 
